/* pppmon/pppstat.c
 *
 * Description:
 * Get stats from pppmon and display it. Just for testing, really...
 *
 * This software is in the public domain.
 *
 * Please send all bug reports, requests for information, etc. to:
 *   Calle Karlsson
 *   KaSH Software AB
 *   calle@kash.se
 * 
 * History:
 * 950525 ckn Initial coding
 * EndHistory.
 */


#include "pppmon.h"


static int ConnectTo (char * HostName, char * Service, char * Protocol);

int
main (int argc, char ** argv)
{
   int fd;
   char * HostName = "localhost";
   DclPPPMonitorMsg PMP [1];
   float MinutesUp;

   if (argc > 1)
     HostName = argv [1];
   
   if ((fd = ConnectTo (HostName, "pppmon", "tcp")) < 0)
   {
      printf ("Couldn't connect to %s\n", HostName);
      exit (1);
   }

   while (read (fd, PMP, sizeof (PMP)) == sizeof (PMP))
   {
/**/     PMP->UpTime = ntohl (PMP->UpTime);
/**/     PMP->TimeSpent = ntohl (PMP->TimeSpent);
/**/     PMP->RBytes = ntohl (PMP->RBytes);
/**/     PMP->SBytes = ntohl (PMP->SBytes);

      if (! PMP->UpTime)
      {
         printf ("[Link down]\n");
         continue;
      }
      
      MinutesUp = PMP->UpTime / 60.0;

      fprintf (stderr, "Up for %.2f minutes: %7.2f bps\n", 
	       MinutesUp,
	       (PMP->RBytes+PMP->SBytes) * 1000 / (float) PMP->TimeSpent);
   }

   close (fd);
   exit (0);
}


static int
ConnectTo (char * HostName, char * Service, char * Protocol)
{
   struct servent * sp;
   struct hostent * hp;
   struct sockaddr_in Addr [1];
   int fd;
   
   if (! (sp = getservbyname (Service, Protocol)))
   {
      perror ("getservbyname");
      return -1;
   }

   if ((fd = socket (AF_INET, SOCK_STREAM, 0)) < 0)
   {
      perror ("socket");
      return -1;
   }

   if (hp = gethostbyname (HostName))
      memcpy (& Addr->sin_addr, hp->h_addr, hp->h_length);
   else
   {
      unsigned long f;
      
      if ((f = inet_addr (HostName)) < 0)
      {
         printf ("Unknown host (%s)\n", HostName);
         return(-1);
      }
      memcpy (& Addr->sin_addr, & f, sizeof (f));
   }
   Addr->sin_family = AF_INET;
   Addr->sin_port = sp->s_port;
   
   if (connect (fd, (struct sockaddr *) Addr, sizeof (Addr)) < 0)
   {
      perror ("connect");
      return (-1);
   }

   return fd;
}
